# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogment/api/model_registry.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogment/api/model_registry.proto',
  package='cogment',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n cogment/api/model_registry.proto\x12\x07\x63ogment\"\x83\x01\n\tModelInfo\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x33\n\tuser_data\x18\x02 \x03(\x0b\x32 .cogment.ModelInfo.UserDataEntry\x1a/\n\rUserDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfd\x01\n\x10ModelVersionInfo\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x16\n\x0eversion_number\x18\x02 \x01(\r\x12\x1a\n\x12\x63reation_timestamp\x18\x03 \x01(\x06\x12\x10\n\x08\x61rchived\x18\x04 \x01(\x08\x12\x11\n\tdata_hash\x18\x05 \x01(\t\x12\x11\n\tdata_size\x18\x06 \x01(\x06\x12:\n\tuser_data\x18\x07 \x03(\x0b\x32\'.cogment.ModelVersionInfo.UserDataEntry\x1a/\n\rUserDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"D\n\x1a\x43reateOrUpdateModelRequest\x12&\n\nmodel_info\x18\x01 \x01(\x0b\x32\x12.cogment.ModelInfo\"\x1a\n\x18\x43reateOrUpdateModelReply\"V\n\x15RetrieveModelsRequest\x12\x11\n\tmodel_ids\x18\x01 \x03(\t\x12\x14\n\x0cmodels_count\x18\x03 \x01(\r\x12\x14\n\x0cmodel_handle\x18\x04 \x01(\t\"Y\n\x13RetrieveModelsReply\x12\'\n\x0bmodel_infos\x18\x01 \x03(\x0b\x32\x12.cogment.ModelInfo\x12\x19\n\x11next_model_handle\x18\x02 \x01(\t\"&\n\x12\x44\x65leteModelRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\"\x12\n\x10\x44\x65leteModelReply\"\xef\x01\n\x19\x43reateVersionRequestChunk\x12;\n\x06header\x18\x01 \x01(\x0b\x32).cogment.CreateVersionRequestChunk.HeaderH\x00\x12\x37\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.cogment.CreateVersionRequestChunk.BodyH\x00\x1a\x39\n\x06Header\x12/\n\x0cversion_info\x18\x01 \x01(\x0b\x32\x19.cogment.ModelVersionInfo\x1a\x1a\n\x04\x42ody\x12\x12\n\ndata_chunk\x18\x01 \x01(\x0c\x42\x05\n\x03msg\"E\n\x12\x43reateVersionReply\x12/\n\x0cversion_info\x18\x01 \x01(\x0b\x32\x19.cogment.ModelVersionInfo\"x\n\x1bRetrieveVersionInfosRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x17\n\x0fversion_numbers\x18\x02 \x03(\x05\x12\x16\n\x0eversions_count\x18\x03 \x01(\r\x12\x16\n\x0eversion_handle\x18\x04 \x01(\t\"j\n\x19RetrieveVersionInfosReply\x12\x30\n\rversion_infos\x18\x01 \x03(\x0b\x32\x19.cogment.ModelVersionInfo\x12\x1b\n\x13next_version_handle\x18\x02 \x01(\t\"F\n\x1aRetrieveVersionDataRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x16\n\x0eversion_number\x18\x02 \x01(\x05\"3\n\x1dRetrieveVersionDataReplyChunk\x12\x12\n\ndata_chunk\x18\x01 \x01(\x0c\x32\xaf\x04\n\x0fModelRegistrySP\x12_\n\x13\x43reateOrUpdateModel\x12#.cogment.CreateOrUpdateModelRequest\x1a!.cogment.CreateOrUpdateModelReply\"\x00\x12G\n\x0b\x44\x65leteModel\x12\x1b.cogment.DeleteModelRequest\x1a\x19.cogment.DeleteModelReply\"\x00\x12P\n\x0eRetrieveModels\x12\x1e.cogment.RetrieveModelsRequest\x1a\x1c.cogment.RetrieveModelsReply\"\x00\x12T\n\rCreateVersion\x12\".cogment.CreateVersionRequestChunk\x1a\x1b.cogment.CreateVersionReply\"\x00(\x01\x12\x62\n\x14RetrieveVersionInfos\x12$.cogment.RetrieveVersionInfosRequest\x1a\".cogment.RetrieveVersionInfosReply\"\x00\x12\x66\n\x13RetrieveVersionData\x12#.cogment.RetrieveVersionDataRequest\x1a&.cogment.RetrieveVersionDataReplyChunk\"\x00\x30\x01\x62\x06proto3'
)




_MODELINFO_USERDATAENTRY = _descriptor.Descriptor(
  name='UserDataEntry',
  full_name='cogment.ModelInfo.UserDataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='cogment.ModelInfo.UserDataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='cogment.ModelInfo.UserDataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=177,
)

_MODELINFO = _descriptor.Descriptor(
  name='ModelInfo',
  full_name='cogment.ModelInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_id', full_name='cogment.ModelInfo.model_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_data', full_name='cogment.ModelInfo.user_data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MODELINFO_USERDATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46,
  serialized_end=177,
)


_MODELVERSIONINFO_USERDATAENTRY = _descriptor.Descriptor(
  name='UserDataEntry',
  full_name='cogment.ModelVersionInfo.UserDataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='cogment.ModelVersionInfo.UserDataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='cogment.ModelVersionInfo.UserDataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=177,
)

_MODELVERSIONINFO = _descriptor.Descriptor(
  name='ModelVersionInfo',
  full_name='cogment.ModelVersionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_id', full_name='cogment.ModelVersionInfo.model_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_number', full_name='cogment.ModelVersionInfo.version_number', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creation_timestamp', full_name='cogment.ModelVersionInfo.creation_timestamp', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='archived', full_name='cogment.ModelVersionInfo.archived', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_hash', full_name='cogment.ModelVersionInfo.data_hash', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_size', full_name='cogment.ModelVersionInfo.data_size', index=5,
      number=6, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_data', full_name='cogment.ModelVersionInfo.user_data', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MODELVERSIONINFO_USERDATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=180,
  serialized_end=433,
)


_CREATEORUPDATEMODELREQUEST = _descriptor.Descriptor(
  name='CreateOrUpdateModelRequest',
  full_name='cogment.CreateOrUpdateModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_info', full_name='cogment.CreateOrUpdateModelRequest.model_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=435,
  serialized_end=503,
)


_CREATEORUPDATEMODELREPLY = _descriptor.Descriptor(
  name='CreateOrUpdateModelReply',
  full_name='cogment.CreateOrUpdateModelReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=505,
  serialized_end=531,
)


_RETRIEVEMODELSREQUEST = _descriptor.Descriptor(
  name='RetrieveModelsRequest',
  full_name='cogment.RetrieveModelsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_ids', full_name='cogment.RetrieveModelsRequest.model_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='models_count', full_name='cogment.RetrieveModelsRequest.models_count', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model_handle', full_name='cogment.RetrieveModelsRequest.model_handle', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=533,
  serialized_end=619,
)


_RETRIEVEMODELSREPLY = _descriptor.Descriptor(
  name='RetrieveModelsReply',
  full_name='cogment.RetrieveModelsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_infos', full_name='cogment.RetrieveModelsReply.model_infos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_model_handle', full_name='cogment.RetrieveModelsReply.next_model_handle', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=621,
  serialized_end=710,
)


_DELETEMODELREQUEST = _descriptor.Descriptor(
  name='DeleteModelRequest',
  full_name='cogment.DeleteModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_id', full_name='cogment.DeleteModelRequest.model_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=712,
  serialized_end=750,
)


_DELETEMODELREPLY = _descriptor.Descriptor(
  name='DeleteModelReply',
  full_name='cogment.DeleteModelReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=752,
  serialized_end=770,
)


_CREATEVERSIONREQUESTCHUNK_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='cogment.CreateVersionRequestChunk.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version_info', full_name='cogment.CreateVersionRequestChunk.Header.version_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=920,
  serialized_end=977,
)

_CREATEVERSIONREQUESTCHUNK_BODY = _descriptor.Descriptor(
  name='Body',
  full_name='cogment.CreateVersionRequestChunk.Body',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_chunk', full_name='cogment.CreateVersionRequestChunk.Body.data_chunk', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=979,
  serialized_end=1005,
)

_CREATEVERSIONREQUESTCHUNK = _descriptor.Descriptor(
  name='CreateVersionRequestChunk',
  full_name='cogment.CreateVersionRequestChunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='cogment.CreateVersionRequestChunk.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='cogment.CreateVersionRequestChunk.body', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEVERSIONREQUESTCHUNK_HEADER, _CREATEVERSIONREQUESTCHUNK_BODY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='msg', full_name='cogment.CreateVersionRequestChunk.msg',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=773,
  serialized_end=1012,
)


_CREATEVERSIONREPLY = _descriptor.Descriptor(
  name='CreateVersionReply',
  full_name='cogment.CreateVersionReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version_info', full_name='cogment.CreateVersionReply.version_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1014,
  serialized_end=1083,
)


_RETRIEVEVERSIONINFOSREQUEST = _descriptor.Descriptor(
  name='RetrieveVersionInfosRequest',
  full_name='cogment.RetrieveVersionInfosRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_id', full_name='cogment.RetrieveVersionInfosRequest.model_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_numbers', full_name='cogment.RetrieveVersionInfosRequest.version_numbers', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='versions_count', full_name='cogment.RetrieveVersionInfosRequest.versions_count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_handle', full_name='cogment.RetrieveVersionInfosRequest.version_handle', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1085,
  serialized_end=1205,
)


_RETRIEVEVERSIONINFOSREPLY = _descriptor.Descriptor(
  name='RetrieveVersionInfosReply',
  full_name='cogment.RetrieveVersionInfosReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version_infos', full_name='cogment.RetrieveVersionInfosReply.version_infos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_version_handle', full_name='cogment.RetrieveVersionInfosReply.next_version_handle', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1207,
  serialized_end=1313,
)


_RETRIEVEVERSIONDATAREQUEST = _descriptor.Descriptor(
  name='RetrieveVersionDataRequest',
  full_name='cogment.RetrieveVersionDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_id', full_name='cogment.RetrieveVersionDataRequest.model_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_number', full_name='cogment.RetrieveVersionDataRequest.version_number', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1315,
  serialized_end=1385,
)


_RETRIEVEVERSIONDATAREPLYCHUNK = _descriptor.Descriptor(
  name='RetrieveVersionDataReplyChunk',
  full_name='cogment.RetrieveVersionDataReplyChunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_chunk', full_name='cogment.RetrieveVersionDataReplyChunk.data_chunk', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1387,
  serialized_end=1438,
)

_MODELINFO_USERDATAENTRY.containing_type = _MODELINFO
_MODELINFO.fields_by_name['user_data'].message_type = _MODELINFO_USERDATAENTRY
_MODELVERSIONINFO_USERDATAENTRY.containing_type = _MODELVERSIONINFO
_MODELVERSIONINFO.fields_by_name['user_data'].message_type = _MODELVERSIONINFO_USERDATAENTRY
_CREATEORUPDATEMODELREQUEST.fields_by_name['model_info'].message_type = _MODELINFO
_RETRIEVEMODELSREPLY.fields_by_name['model_infos'].message_type = _MODELINFO
_CREATEVERSIONREQUESTCHUNK_HEADER.fields_by_name['version_info'].message_type = _MODELVERSIONINFO
_CREATEVERSIONREQUESTCHUNK_HEADER.containing_type = _CREATEVERSIONREQUESTCHUNK
_CREATEVERSIONREQUESTCHUNK_BODY.containing_type = _CREATEVERSIONREQUESTCHUNK
_CREATEVERSIONREQUESTCHUNK.fields_by_name['header'].message_type = _CREATEVERSIONREQUESTCHUNK_HEADER
_CREATEVERSIONREQUESTCHUNK.fields_by_name['body'].message_type = _CREATEVERSIONREQUESTCHUNK_BODY
_CREATEVERSIONREQUESTCHUNK.oneofs_by_name['msg'].fields.append(
  _CREATEVERSIONREQUESTCHUNK.fields_by_name['header'])
_CREATEVERSIONREQUESTCHUNK.fields_by_name['header'].containing_oneof = _CREATEVERSIONREQUESTCHUNK.oneofs_by_name['msg']
_CREATEVERSIONREQUESTCHUNK.oneofs_by_name['msg'].fields.append(
  _CREATEVERSIONREQUESTCHUNK.fields_by_name['body'])
_CREATEVERSIONREQUESTCHUNK.fields_by_name['body'].containing_oneof = _CREATEVERSIONREQUESTCHUNK.oneofs_by_name['msg']
_CREATEVERSIONREPLY.fields_by_name['version_info'].message_type = _MODELVERSIONINFO
_RETRIEVEVERSIONINFOSREPLY.fields_by_name['version_infos'].message_type = _MODELVERSIONINFO
DESCRIPTOR.message_types_by_name['ModelInfo'] = _MODELINFO
DESCRIPTOR.message_types_by_name['ModelVersionInfo'] = _MODELVERSIONINFO
DESCRIPTOR.message_types_by_name['CreateOrUpdateModelRequest'] = _CREATEORUPDATEMODELREQUEST
DESCRIPTOR.message_types_by_name['CreateOrUpdateModelReply'] = _CREATEORUPDATEMODELREPLY
DESCRIPTOR.message_types_by_name['RetrieveModelsRequest'] = _RETRIEVEMODELSREQUEST
DESCRIPTOR.message_types_by_name['RetrieveModelsReply'] = _RETRIEVEMODELSREPLY
DESCRIPTOR.message_types_by_name['DeleteModelRequest'] = _DELETEMODELREQUEST
DESCRIPTOR.message_types_by_name['DeleteModelReply'] = _DELETEMODELREPLY
DESCRIPTOR.message_types_by_name['CreateVersionRequestChunk'] = _CREATEVERSIONREQUESTCHUNK
DESCRIPTOR.message_types_by_name['CreateVersionReply'] = _CREATEVERSIONREPLY
DESCRIPTOR.message_types_by_name['RetrieveVersionInfosRequest'] = _RETRIEVEVERSIONINFOSREQUEST
DESCRIPTOR.message_types_by_name['RetrieveVersionInfosReply'] = _RETRIEVEVERSIONINFOSREPLY
DESCRIPTOR.message_types_by_name['RetrieveVersionDataRequest'] = _RETRIEVEVERSIONDATAREQUEST
DESCRIPTOR.message_types_by_name['RetrieveVersionDataReplyChunk'] = _RETRIEVEVERSIONDATAREPLYCHUNK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ModelInfo = _reflection.GeneratedProtocolMessageType('ModelInfo', (_message.Message,), {

  'UserDataEntry' : _reflection.GeneratedProtocolMessageType('UserDataEntry', (_message.Message,), {
    'DESCRIPTOR' : _MODELINFO_USERDATAENTRY,
    '__module__' : 'cogment.api.model_registry_pb2'
    # @@protoc_insertion_point(class_scope:cogment.ModelInfo.UserDataEntry)
    })
  ,
  'DESCRIPTOR' : _MODELINFO,
  '__module__' : 'cogment.api.model_registry_pb2'
  # @@protoc_insertion_point(class_scope:cogment.ModelInfo)
  })
_sym_db.RegisterMessage(ModelInfo)
_sym_db.RegisterMessage(ModelInfo.UserDataEntry)

ModelVersionInfo = _reflection.GeneratedProtocolMessageType('ModelVersionInfo', (_message.Message,), {

  'UserDataEntry' : _reflection.GeneratedProtocolMessageType('UserDataEntry', (_message.Message,), {
    'DESCRIPTOR' : _MODELVERSIONINFO_USERDATAENTRY,
    '__module__' : 'cogment.api.model_registry_pb2'
    # @@protoc_insertion_point(class_scope:cogment.ModelVersionInfo.UserDataEntry)
    })
  ,
  'DESCRIPTOR' : _MODELVERSIONINFO,
  '__module__' : 'cogment.api.model_registry_pb2'
  # @@protoc_insertion_point(class_scope:cogment.ModelVersionInfo)
  })
_sym_db.RegisterMessage(ModelVersionInfo)
_sym_db.RegisterMessage(ModelVersionInfo.UserDataEntry)

CreateOrUpdateModelRequest = _reflection.GeneratedProtocolMessageType('CreateOrUpdateModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEORUPDATEMODELREQUEST,
  '__module__' : 'cogment.api.model_registry_pb2'
  # @@protoc_insertion_point(class_scope:cogment.CreateOrUpdateModelRequest)
  })
_sym_db.RegisterMessage(CreateOrUpdateModelRequest)

CreateOrUpdateModelReply = _reflection.GeneratedProtocolMessageType('CreateOrUpdateModelReply', (_message.Message,), {
  'DESCRIPTOR' : _CREATEORUPDATEMODELREPLY,
  '__module__' : 'cogment.api.model_registry_pb2'
  # @@protoc_insertion_point(class_scope:cogment.CreateOrUpdateModelReply)
  })
_sym_db.RegisterMessage(CreateOrUpdateModelReply)

RetrieveModelsRequest = _reflection.GeneratedProtocolMessageType('RetrieveModelsRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEMODELSREQUEST,
  '__module__' : 'cogment.api.model_registry_pb2'
  # @@protoc_insertion_point(class_scope:cogment.RetrieveModelsRequest)
  })
_sym_db.RegisterMessage(RetrieveModelsRequest)

RetrieveModelsReply = _reflection.GeneratedProtocolMessageType('RetrieveModelsReply', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEMODELSREPLY,
  '__module__' : 'cogment.api.model_registry_pb2'
  # @@protoc_insertion_point(class_scope:cogment.RetrieveModelsReply)
  })
_sym_db.RegisterMessage(RetrieveModelsReply)

DeleteModelRequest = _reflection.GeneratedProtocolMessageType('DeleteModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELREQUEST,
  '__module__' : 'cogment.api.model_registry_pb2'
  # @@protoc_insertion_point(class_scope:cogment.DeleteModelRequest)
  })
_sym_db.RegisterMessage(DeleteModelRequest)

DeleteModelReply = _reflection.GeneratedProtocolMessageType('DeleteModelReply', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELREPLY,
  '__module__' : 'cogment.api.model_registry_pb2'
  # @@protoc_insertion_point(class_scope:cogment.DeleteModelReply)
  })
_sym_db.RegisterMessage(DeleteModelReply)

CreateVersionRequestChunk = _reflection.GeneratedProtocolMessageType('CreateVersionRequestChunk', (_message.Message,), {

  'Header' : _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), {
    'DESCRIPTOR' : _CREATEVERSIONREQUESTCHUNK_HEADER,
    '__module__' : 'cogment.api.model_registry_pb2'
    # @@protoc_insertion_point(class_scope:cogment.CreateVersionRequestChunk.Header)
    })
  ,

  'Body' : _reflection.GeneratedProtocolMessageType('Body', (_message.Message,), {
    'DESCRIPTOR' : _CREATEVERSIONREQUESTCHUNK_BODY,
    '__module__' : 'cogment.api.model_registry_pb2'
    # @@protoc_insertion_point(class_scope:cogment.CreateVersionRequestChunk.Body)
    })
  ,
  'DESCRIPTOR' : _CREATEVERSIONREQUESTCHUNK,
  '__module__' : 'cogment.api.model_registry_pb2'
  # @@protoc_insertion_point(class_scope:cogment.CreateVersionRequestChunk)
  })
_sym_db.RegisterMessage(CreateVersionRequestChunk)
_sym_db.RegisterMessage(CreateVersionRequestChunk.Header)
_sym_db.RegisterMessage(CreateVersionRequestChunk.Body)

CreateVersionReply = _reflection.GeneratedProtocolMessageType('CreateVersionReply', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVERSIONREPLY,
  '__module__' : 'cogment.api.model_registry_pb2'
  # @@protoc_insertion_point(class_scope:cogment.CreateVersionReply)
  })
_sym_db.RegisterMessage(CreateVersionReply)

RetrieveVersionInfosRequest = _reflection.GeneratedProtocolMessageType('RetrieveVersionInfosRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEVERSIONINFOSREQUEST,
  '__module__' : 'cogment.api.model_registry_pb2'
  # @@protoc_insertion_point(class_scope:cogment.RetrieveVersionInfosRequest)
  })
_sym_db.RegisterMessage(RetrieveVersionInfosRequest)

RetrieveVersionInfosReply = _reflection.GeneratedProtocolMessageType('RetrieveVersionInfosReply', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEVERSIONINFOSREPLY,
  '__module__' : 'cogment.api.model_registry_pb2'
  # @@protoc_insertion_point(class_scope:cogment.RetrieveVersionInfosReply)
  })
_sym_db.RegisterMessage(RetrieveVersionInfosReply)

RetrieveVersionDataRequest = _reflection.GeneratedProtocolMessageType('RetrieveVersionDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEVERSIONDATAREQUEST,
  '__module__' : 'cogment.api.model_registry_pb2'
  # @@protoc_insertion_point(class_scope:cogment.RetrieveVersionDataRequest)
  })
_sym_db.RegisterMessage(RetrieveVersionDataRequest)

RetrieveVersionDataReplyChunk = _reflection.GeneratedProtocolMessageType('RetrieveVersionDataReplyChunk', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEVERSIONDATAREPLYCHUNK,
  '__module__' : 'cogment.api.model_registry_pb2'
  # @@protoc_insertion_point(class_scope:cogment.RetrieveVersionDataReplyChunk)
  })
_sym_db.RegisterMessage(RetrieveVersionDataReplyChunk)


_MODELINFO_USERDATAENTRY._options = None
_MODELVERSIONINFO_USERDATAENTRY._options = None

_MODELREGISTRYSP = _descriptor.ServiceDescriptor(
  name='ModelRegistrySP',
  full_name='cogment.ModelRegistrySP',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1441,
  serialized_end=2000,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateOrUpdateModel',
    full_name='cogment.ModelRegistrySP.CreateOrUpdateModel',
    index=0,
    containing_service=None,
    input_type=_CREATEORUPDATEMODELREQUEST,
    output_type=_CREATEORUPDATEMODELREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteModel',
    full_name='cogment.ModelRegistrySP.DeleteModel',
    index=1,
    containing_service=None,
    input_type=_DELETEMODELREQUEST,
    output_type=_DELETEMODELREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RetrieveModels',
    full_name='cogment.ModelRegistrySP.RetrieveModels',
    index=2,
    containing_service=None,
    input_type=_RETRIEVEMODELSREQUEST,
    output_type=_RETRIEVEMODELSREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateVersion',
    full_name='cogment.ModelRegistrySP.CreateVersion',
    index=3,
    containing_service=None,
    input_type=_CREATEVERSIONREQUESTCHUNK,
    output_type=_CREATEVERSIONREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RetrieveVersionInfos',
    full_name='cogment.ModelRegistrySP.RetrieveVersionInfos',
    index=4,
    containing_service=None,
    input_type=_RETRIEVEVERSIONINFOSREQUEST,
    output_type=_RETRIEVEVERSIONINFOSREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RetrieveVersionData',
    full_name='cogment.ModelRegistrySP.RetrieveVersionData',
    index=5,
    containing_service=None,
    input_type=_RETRIEVEVERSIONDATAREQUEST,
    output_type=_RETRIEVEVERSIONDATAREPLYCHUNK,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MODELREGISTRYSP)

DESCRIPTOR.services_by_name['ModelRegistrySP'] = _MODELREGISTRYSP

# @@protoc_insertion_point(module_scope)
